#!/usr/bin/env python
# setup.py - Build system for Ubuntu One Control Panel package
#
# Author: Natalia B. Bidart <natalia.bidart@canonical.com>
#
# Copyright 2010 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Setup.py: build, distribute, clean."""

import os
import sys

try:
    import DistUtilsExtra.auto
    from DistUtilsExtra.command import build_extra
except ImportError:
    print >> sys.stderr, 'To build this program you need '\
                         'https://launchpad.net/python-distutils-extra'
    sys.exit(1)
assert DistUtilsExtra.auto.__version__ >= '2.18', \
       'needs DistUtilsExtra.auto >= 2.18'

from distutils.core import setup
from distutils.spawn import find_executable
from distutils.command import clean, build

POT_FILE = 'po/ubuntuone-control-panel.pot'
SERVICE_NAME = 'com.ubuntuone.controlpanel'
SERVICE_FILE = 'data/%s.service' % SERVICE_NAME
SERVICE_CONTENT = """[D-BUS Service]
Name=%s
Exec=/usr/lib/ubuntuone-control-panel-backend
""" % SERVICE_NAME

CLEANFILES = [SERVICE_FILE, POT_FILE]


class ControlPanelBuild(build_extra.build_extra):
    """Class to build the extra files."""

    description = 'build extra files needed by ubuntuone-control-panel'

    def run(self):
        """Do the build."""

        with open(SERVICE_FILE, 'w') as out_file:
            out_file.write(SERVICE_CONTENT)

        # Run the parent build command
        build_extra.build_extra.run(self)


class ControlPanelClean(clean.clean):
    """Class to clean up after the build."""

    description = 'Clean up built files.'

    def run(self):
        """Clean up the built files."""
        for built_file in CLEANFILES:
            if os.path.exists(built_file):
                os.unlink(built_file)

        # Run the parent clean command
        clean.clean.run(self)


DistUtilsExtra.auto.setup(
    name='ubuntuone-control-panel',
    version='0.0.1',
    license='GPL v3',
    author='Natalia Bidart',
    author_email='natalia.bidart@canonical.com',
    description='Ubuntu One Control Panel',
    long_description='Desktop application to manage a Ubuntu One account',
    url='https://launchpad.net/ubuntuone-control-panel',
    packages=['ubuntuone.controlpanel'],
    data_files=[
        ('share/dbus-1/services', ['data/com.ubuntuone.controlpanel.service']),
        ('lib/ubuntuone-client', ['bin/ubuntuone-control-panel',
                                  'bin/ubuntuone-control-panel-backend']),
        ('share/ubuntuone-client/data', ['data/*.ui'])],
    cmdclass={
        'build' : ControlPanelBuild,
        'clean' : ControlPanelClean})
