# -*- coding: utf-8 -*-

# Authors: Alejandro J. Cura <alecu@canonical.com>
#
# Copyright 2010 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""A backend for the Ubuntu One Control Panel."""

from twisted.internet.defer import inlineCallbacks, returnValue

from ubuntuone.controlpanel import dbus_client
from ubuntuone.controlpanel.webclient import WebClient


class ControlBackend(object):
    """The control panel backend."""

    def __init__(self):
        """Initialize the webclient."""
        self.wc = WebClient(dbus_client.get_credentials)

    @inlineCallbacks
    def account_info(self):
        """Get the user account info."""
        result = {}

        account_info = yield self.wc.call_api("account/")
        result["type"] = account_info["subscription"]["description"]
        result["name"] = account_info["nickname"]
        result["email"] = account_info["email"]

        quota_info = yield self.wc.call_api("quota/")
        result["quota_total"] = str(quota_info["total"])
        result["quota_used"] = str(quota_info["used"])

        returnValue(result)
