# -*- coding: utf-8 -*-

# Authors: Alejandro J. Cura <alecu@canonical.com>
#
# Copyright 2010 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Client to use other DBus services."""

import dbus.service
import ubuntu_sso

from twisted.internet import defer

# pylint: disable=F0401,E0611
from ubuntuone.clientdefs import APP_NAME
# pylint: enable=F0401,E0611


class CredentialsError(Exception):
    """No credentials could be retrieved."""


def no_op(*a):
    """Do nothing"""


def get_credentials():
    """Get the credentials from the ubuntu-sso-client."""
    d = defer.Deferred()
    bus = dbus.SessionBus()
    obj = bus.get_object(bus_name=ubuntu_sso.DBUS_BUS_NAME,
                         object_path=ubuntu_sso.DBUS_CRED_PATH,
                         follow_name_owner_changes=True)
    proxy = dbus.Interface(object=obj,
                           dbus_interface=ubuntu_sso.DBUS_IFACE_CRED_NAME)

    def found_credentials(app_name, creds):
        """Credentials have been found."""
        # TODO: must check for the right app_name
        d.callback(creds)

    def credentials_error(app_name, error_message, detailed_error):
        """No credentials could be retrieved."""
        # TODO: must check for the right app_name
        d.errback(CredentialsError(app_name, error_message, detailed_error))

    foundsig = proxy.connect_to_signal("CredentialsFound", found_credentials)
    errorsig = proxy.connect_to_signal("CredentialsError", credentials_error)
    proxy.login_or_register_to_get_credentials(APP_NAME, "tcurl", "help", 0,
                                               reply_handler=no_op,
                                               error_handler=d.errback)

    def cleanup_signals(result):
        """Remove signals after use."""
        foundsig.remove()
        errorsig.remove()
        return result

    d.addBoth(cleanup_signals)
    return d
