# -*- coding: utf-8 -*-

# Authors: Natalia B Bidart <natalia.bidart@canonical.com>
#
# Copyright 2010 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""The test suite for the control panel utilities."""

import os

from twisted.trial.unittest import TestCase

from ubuntuone.controlpanel import utils


class GetDataTestCase(TestCase):
    """Test case for get_data_dir and get_data_file."""

    def test_get_data_dir_relative(self):
        """The relative path for the data directory is correctly retrieved."""
        module = os.path.dirname(utils.__file__)
        expected = os.path.abspath(os.path.join(module, os.path.pardir,
                                                os.path.pardir, 'data'))
        result = utils.get_data_dir()
        self.assertEqual(expected, result)

    def test_get_data_file(self):
        """The path for a data file is correctly retrieved."""
        dummy_dir = '/yadda/yadda'
        dummy_file = 'test.png'
        self.patch(utils, 'get_data_dir', lambda: dummy_dir)
        result = utils.get_data_file(dummy_file)
        self.assertEqual(os.path.join(dummy_dir, dummy_file), result)
