# Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
#
# Copyright 2009-2010 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Test utilities."""

import logging


class MementoHandler(logging.Handler):
    """ A handler class which store logging records in a list """

    def __init__(self, *args, **kwargs):
        """ Create the instance, and add a records attribute. """
        logging.Handler.__init__(self, *args, **kwargs)
        self.records = []

    def emit(self, record):
        """ Just add the record to self.records. """
        self.records.append(record)

    def check(self, level, *msgs):
        """Verifies that the msgs are logged in the specified level."""
        for rec in self.records:
            if rec.levelno == level and all(m in rec.message for m in msgs):
                return True
        return False

    def check_debug(self, *msgs):
        """Shortcut for checking in DEBUG."""
        return self.check(logging.DEBUG, *msgs)

    def check_info(self, *msgs):
        """Shortcut for checking in INFO."""
        return self.check(logging.INFO, *msgs)

    def check_warning(self, *msgs):
        """Shortcut for checking in WARNING."""
        return self.check(logging.WARNING, *msgs)

    def check_error(self, *msgs):
        """Shortcut for checking in ERROR."""
        return self.check(logging.ERROR, *msgs)
