# -*- coding: utf-8 -*-

# Authors: Natalia B Bidart <natalia.bidart@canonical.com>
#
# Copyright 2010 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Miscellaneous utilities."""

import os

from functools import wraps

from ubuntuone.controlpanel.logger import setup_logging


logger = setup_logging('utils')


def get_data_dir():
    """Return the absolute path to this project's data/ dir.

    Support symlinks, and priorize local (relative) data/ dir.
    """
    module = os.path.dirname(__file__)
    result = os.path.abspath(os.path.join(module, os.path.pardir,
                                          os.path.pardir, 'data'))
    return result


def get_data_file(filename):
    """Return the absolute path to 'filename' within data/ dir."""
    return os.path.join(get_data_dir(), filename)


def log_call(log_func):
    """Decorator to add log info using 'log_func'."""

    def middle(f):
        """Add logging when calling 'f'."""

        @wraps(f)
        def inner(*args, **kwargs):
            """Call f(*args, **kwargs)."""
            log_func('%s: args %r, kwargs %r.', f.__name__, args, kwargs)
            res = f(*args, **kwargs)
            return res

        return inner

    return middle
